
/*
 *  dyncnn is a deep-learning algorithm for the prediction of
 *  interacting object dynamics
 *
 *  Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 *  Written by Francois Fleuret <francois.fleuret@idiap.ch>
 *
 *  This file is part of dyncnn.
 *
 *  dyncnn is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License version 3 as
 *  published by the Free Software Foundation.
 *
 *  dyncnn is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with dyncnn.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef MISC_H
#define MISC_H

#include <float.h>
#include <stdlib.h>

#ifdef DEBUG
#define ASSERT(x, s) if(!(x)) { std::cerr << "ASSERT FAILED IN " << __FILE__ << ":" << __LINE__ << " [" << (s) << "]\n"; abort(); }
#else
#define ASSERT(x, s)
#endif

// typedef float scalar_t;
typedef double scalar_t;

inline scalar_t sq(scalar_t x) { return x*x; }

inline scalar_t prod_vect(scalar_t x1, scalar_t y1, scalar_t x2, scalar_t y2) {
  return x1 * y2 - x2 * y1;
}

struct Couple {
  int index;
  scalar_t value;
};

int compare_couple(const void *a, const void *b);

#endif
