#!/usr/bin/env python-for-pytorch

import torch
import torchvision
from torchvision import datasets

######################################################################

def sequences_to_image(x):
    from PIL import Image

    nb_sequences = x.size(0)
    nb_images_per_sequences = x.size(1)
    nb_channels = 3

    if x.size(2) != nb_channels:
        print('Can only handle 3 channel tensors.')
        exit(1)

    height = x.size(3)
    width = x.size(4)
    gap = 1
    gap_color = (0, 128, 255)

    result = torch.ByteTensor(nb_channels,
                              gap + nb_sequences * (height + gap),
                              gap + nb_images_per_sequences * (width + gap))

    result[0].fill_(gap_color[0])
    result[1].fill_(gap_color[1])
    result[2].fill_(gap_color[2])

    for s in range(0, nb_sequences):
        for i in range(0, nb_images_per_sequences):
            result.narrow(1, gap + s * (height + gap), height).narrow(2, gap + i * (width + gap), width).copy_(x[s][i])

    result_numpy = result.cpu().byte().transpose(0, 2).transpose(0, 1).numpy()

    return Image.fromarray(result_numpy, 'RGB')

######################################################################

from _ext import mylib

x = torch.ByteTensor()

mylib.generate_sequence(10, x)

sequences_to_image(x).save('sequences.png')
